<no title> — CALCEPH - C language 3.4.1 documentation

The units of PV.
This integer is a sum of some unit constants (CALCEPH_UNIT_???) and/or the constant `CALCEPH_USE_NAIFID`.
If the unit contains `CALCEPH_USE_NAIFID`, the NAIF identification numbering system is used for the target and the center (NAIF identification numbers for the list).
If the unit doesnot contain `CALCEPH_USE_NAIFID`, the old number system is used for the target and the center (see the list in the function `calceph_compute()`).